Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Inspector2.

Actions, resources, and condition keys for Amazon Inspector2 - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Inspector2

Amazon Inspector2 (service prefix: `inspector2` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon Inspector2
- Resource types defined by Amazon Inspector2
- Condition keys for Amazon Inspector2

## Actions defined by Amazon Inspector2

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AssociateMember | Grants permission to associate an account with an Amazon Inspector administrator account | Write |  |  |
BatchGetAccountStatus | Grants permission to retrieve information about Amazon Inspector accounts for an account | Read |  |  |
BatchGetCodeSnippet | Grants permission to retrieve code snippet information about one or more code vulnerability findings | Read |  |  |
BatchGetFreeTrialInfo | Grants permission to retrieve free trial period eligibility about Amazon Inspector accounts for an account | Read |  |  |
BatchGetMemberEc2DeepInspectionStatus | Grants permission to delegated administrator to retrieve ec2 deep inspection status of member accounts | Read |  |  |
BatchUpdateMemberEc2DeepInspectionStatus | Grants permission to update ec2 deep inspection status by delegated administrator for its associated member accounts | Write |  |  |
CancelFindingsReport | Grants permission to cancel the generation of a findings report | Write |  |  |
CancelSbomExport | Grants permission to cancel the generation of an SBOM report | Write |  |  |
CreateFilter | Grants permission to create and define the settings for a findings filter | Write | Filter* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateFindingsReport | Grants permission to request the generation of a findings report | Write |  |  |
CreateSbomExport | Grants permission to request the generation of an SBOM report | Write |  |  |
DeleteFilter | Grants permission to delete a findings filter | Write | Filter* |  |
DescribeOrganizationConfiguration | Grants permission to retrieve information about the Amazon Inspector configuration settings for an AWS organization | Read |  |  |
Disable | Grants permission to disable an Amazon Inspector account | Write |  |  |
DisableDelegatedAdminAccount | Grants permission to disable an account as the delegated Amazon Inspector administrator account for an AWS organization | Write |  |  |
DisassociateMember | Grants permission to an Amazon Inspector administrator account to disassociate from an Inspector member account | Write |  |  |
Enable | Grants permission to enable and specify the configuration settings for a new Amazon Inspector account | Write |  |  |
EnableDelegatedAdminAccount | Grants permission to enable an account as the delegated Amazon Inspector administrator account for an AWS organization | Write |  |  |
GetConfiguration | Grants permission to retrieve information about the Amazon Inspector configuration settings for an AWS account | Read |  |  |
GetDelegatedAdminAccount | Grants permission to retrieve information about the Amazon Inspector administrator account for an account | Read |  |  |
GetEc2DeepInspectionConfiguration | Grants permission to retrieve ec2 deep inspection configuration for standalone accounts, delegated administrator and member account | Read |  |  |
GetEncryptionKey | Grants permission to retrieve information about the KMS key used to encrypt code snippets with | Read |  |  |
GetFindingsReportStatus | Grants permission to retrieve status for a requested findings report | Read |  |  |
GetMember | Grants permission to retrieve information about an account that's associated with an Amazon Inspector administrator account | Read |  |  |
GetSbomExport | Grants permission to retrieve a requested SBOM report | Read |  |  |
ListAccountPermissions | Grants permission to retrieve feature configuration permissions associated with an Amazon Inspector account within an organization | List |  |  |
ListCoverage | Grants permission to retrieve the types of statistics Amazon Inspector can generate for resources Inspector monitors | List |  |  |
ListCoverageStatistics | Grants permission to retrieve statistical data and other information about the resources Amazon Inspector monitors | List |  |  |
ListDelegatedAdminAccounts | Grants permission to retrieve information about the delegated Amazon Inspector administrator account for an AWS organization | List |  |  |
ListFilters | Grants permission to retrieve information about all findings filters | List |  |  |
ListFindingAggregations | Grants permission to retrieve statistical data and other information about Amazon Inspector findings | List |  |  |
ListFindings | Grants permission to retrieve a subset of information about one or more findings | List |  |  |
ListMembers | Grants permission to retrieve information about the Amazon Inspector member accounts that are associated with an Inspector administrator account | List |  |  |
ListTagsForResource | Grants permission to retrieve the tags for an Amazon Inspector resource | Read |  |  |
ListUsageTotals | Grants permission to retrieve aggregated usage data for an account | List |  |  |
ResetEncryptionKey | Grants permission to let a customer reset to use an Amazon-owned KMS key to encrypt code snippets with | Write |  |  |
SearchVulnerabilities | Grants permission to list Amazon Inspector coverage details for a specific vulnerability | Read |  |  |
TagResource | Grants permission to add or update the tags for an Amazon Inspector resource | Tagging |  | aws:RequestTag/${TagKey} aws:TagKeys aws:ResourceTag/${TagKey} |
UntagResource | Grants permission to remove tags from an Amazon Inspector resource | Tagging |  | aws:TagKeys |
UpdateConfiguration | Grants permission to update information about the Amazon Inspector configuration settings for an AWS account | Write |  |  |
UpdateEc2DeepInspectionConfiguration | Grants permission to update ec2 deep inspection configuration by delegated administrator, member and standalone account | Write |  |  |
UpdateEncryptionKey | Grants permission to let a customer use a KMS key to encrypt code snippets with | Write |  |  |
UpdateFilter | Grants permission to update the settings for a findings filter | Write | Filter* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UpdateOrgEc2DeepInspectionConfiguration | Grants permission to update ec2 deep inspection configuration by delegated administrator for its associated member accounts | Write |  |  |
UpdateOrganizationConfiguration | Grants permission to update Amazon Inspector configuration settings for an AWS organization | Write |  |  |

## Resource types defined by Amazon Inspector2

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
Filter | `arn:$ { Partition}:inspector2:$ { Region}:$ { Account}:owner/$ { OwnerId}/filter/$ { FilterId}` | aws:ResourceTag/${TagKey}
Finding | `arn:$ { Partition}:inspector2:$ { Region}:$ { Account}:finding/$ { FindingId}` |

## Condition keys for Amazon Inspector2

Amazon Inspector2 defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters access by tag key-value pairs attached to the resource | String
aws:TagKeys | Filters access by the presence of tag keys in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.